@@ -68,7 +68,7 @@
 #include "gossip-private.h"
 #include "gossip-utils.h"
 
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 #include <libgnomevfs/gnome-vfs.h>
 #endif
 
@@ -76,14 +76,21 @@
 
 #define LOG_PROTOCOL_VERSION   "2.0"
 
-#define LOG_HEADER \
+#define LOG_FILE_HEADER \
     "<?xml version='1.0' encoding='utf-8'?>\n" \
     "<?xml-stylesheet type=\"text/xsl\" href=\"gossip-log.xsl\"?>\n" \
     "<log>\n"
 
-#define LOG_FOOTER \
+#define LOG_FILE_FOOTER \
     "</log>\n"
 
+#define LOG_LINKS_FILE_HEADER \
+    "<?xml version='1.0' encoding='utf-8'?>\n" \
+    "<links>\n"
+
+#define LOG_LINKS_FILE_FOOTER \
+    "</links>\n"
+
 #define LOG_FILENAME_PREFIX       "file://"
 #define LOG_FILENAME_SUFFIX       ".log"
 
@@ -118,6 +125,13 @@ struct _GossipLogSearchHit {
 	gchar         *date;
 };
 
+struct _GossipLogLinkHit {
+	GossipAccount *account;
+	GossipContact *contact;
+	gchar         *date;
+	gchar         *url;
+};
+
 typedef struct {
 	GossipAccount *account;
 	GHashTable    *names;
@@ -140,7 +154,7 @@ typedef enum {
 static void            gossip_log_manager_class_init           (GossipLogManagerClass *klass);
 static void            gossip_log_manager_init                 (GossipLogManager      *manager);
 static void            log_manager_finalize                    (GObject               *object);
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 static void            log_move_contact_dirs                   (GossipLogManager      *manager,
 								const gchar           *log_directory,
 								const gchar           *filename,
@@ -167,7 +181,7 @@ static void            log_handlers_notify_all                 (GossipLogManager
 								GossipChatroom        *chatroom,
 								GossipMessage         *message);
 static gboolean        log_check_dir                           (gchar                **directory);
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 static LogVersion      log_check_version                       (void);
 #endif
 static gboolean        log_check_dir                           (gchar **directory);
@@ -185,8 +199,6 @@ static void            log_get_all_log_files_in_directory      (const gchar
 								GList                **files);
 static void            log_get_all_log_files_for_account_dir   (const gchar           *account_dir,
 								GList                **files);
-static void            log_get_all_log_files_for_type_dir      (const gchar           *type_dir,
-								GList                **files);
 static GossipAccount * log_get_account_from_filename           (GossipLogManager      *manager,
 								const gchar           *filename);
 static gchar *         log_get_date_from_filename              (const gchar           *filename);
@@ -194,10 +206,17 @@ static gchar *         log_get_filename_by_date_for_contact    (GossipContact
 								const gchar           *particular_date);
 static gchar *         log_get_filename_by_date_for_chatroom   (GossipChatroom        *chatroom,
 								const gchar           *particular_date);
+static gchar *         log_get_filename_for_links              (GossipAccount         *account);
 static gboolean        log_set_name                            (GossipLogManager      *manager,
 								GossipContact         *contact);
-static gchar *         log_get_contact_log_dir                 (GossipContact *contact);
-static gchar *         log_get_chatroom_log_dir                (GossipChatroom *chatroom);
+static gchar *         log_get_contact_log_dir                 (GossipContact         *contact);
+static gchar *         log_get_chatroom_log_dir                (GossipChatroom        *chatroom);
+static void            log_set_links_from_message              (GossipLogManager      *manager,
+								GossipContact         *sender, 
+								const gchar           *timestamp, 
+								const gchar           *body);
+static GList *         log_get_links                           (GossipLogManager      *manager, 
+								GossipAccount         *account);
 
 G_DEFINE_TYPE (GossipLogManager, gossip_log_manager, G_TYPE_OBJECT);
 
@@ -259,7 +278,7 @@ gossip_log_manager_new (GossipSession *session)
 	GossipLogManagerPriv *priv;
 	GossipLogManager     *manager;
 	GossipAccountManager *account_manager;
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 	LogVersion            version;
 #endif
 	GList                *accounts, *l;
@@ -288,12 +307,15 @@ gossip_log_manager_new (GossipSession *session)
 			  NULL);
 
 	/* We only support this when running GNOME. */
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
+
 	/* Check for new log protocol version, and if so we fix the
 	 * differences here.
 	 */
 	version = log_check_version ();
-	if (version == LOG_VERSION_0 || version == LOG_VERSION_1) {
+
+	if (version == LOG_VERSION_0 || 
+	    version == LOG_VERSION_1) {
 		GDir        *dir;
 		gchar       *log_directory;
 		const gchar *basename;
@@ -354,12 +376,12 @@ gossip_log_manager_new (GossipSession *session)
 		g_dir_close (dir);
 		g_free (log_directory);
 	}
-#endif /* HAVE_GNOME */
+#endif /* HAVE_PLATFORM_X11 */
 
 	return manager;
 }
 
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 static void
 log_move_contact_dirs (GossipLogManager *manager,
 		       const gchar      *log_directory,
@@ -471,7 +493,7 @@ log_account_renamed_cb (GossipAccount *account,
 			GParamSpec    *param,
 			gpointer       user_data)
 {
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 	const gchar    *old_name;
 	const gchar    *new_name;
 	gchar          *log_directory;
@@ -514,7 +536,7 @@ log_account_renamed_cb (GossipAccount *account,
 static gchar *
 log_escape (const gchar *str)
 {
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 	return gnome_vfs_escape_host_and_path_string (str);
 #else
 	return g_strdup (str);
@@ -524,7 +546,7 @@ log_escape (const gchar *str)
 static gchar *
 log_unescape (const gchar *str)
 {
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 	return gnome_vfs_unescape_string_for_display (str);
 #else
 	return g_strdup (str);
@@ -665,7 +687,7 @@ log_handlers_notify_all (GossipLogManager *manager,
 	g_list_free (handlers);
 }
 
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 static LogVersion
 log_check_version (void)
 {
@@ -694,9 +716,11 @@ log_check_version (void)
 		g_chmod (filename, LOG_FILE_CREATE_MODE);
 		g_free (filename);
 
+
 		/* There is a bug with log version 1.0, the version file was
 		 * not created when gossip creates a new log directory.
-		 * Here we try to guess if we have version_0 or version_1 */
+		 * Here we try to guess if we have version_0 or version_1
+		 */
 		dir = g_dir_open (log_directory, 0, NULL);
 		if (!dir) {
 			gossip_debug (DEBUG_DOMAIN, "Could not open directory:'%s'",
@@ -756,7 +780,7 @@ log_check_version (void)
 	
 	return LOG_VERSION_LAST;
 }
-#endif /* HAVE_GNOME */
+#endif /* HAVE_PLATFORM_X11 */
 
 static gboolean
 log_check_dir (gchar **directory)
@@ -846,7 +870,7 @@ log_get_contact_id_from_filename (const gchar *filename)
 		i++;
 	}
 
-	contact_id = g_strdup (strv[i - 2]);
+	contact_id = log_unescape (strv[i - 2]);
 	g_strfreev (strv);
 
 	return contact_id;
@@ -923,7 +947,6 @@ log_get_chatroom_from_filename (GossipLogManager *manager,
 
 	if (!found) {
 		chatroom = g_object_new (GOSSIP_TYPE_CHATROOM,
-					 "type", GOSSIP_CHATROOM_TYPE_NORMAL,
 					 "account", account,
 					 "name", room,
 					 "server", server,
@@ -986,7 +1009,8 @@ log_get_all_log_files_for_chatrooms_dir (const gchar  *chatrooms_dir,
 }
 
 static void
-log_get_all_log_files_in_directory (const gchar *directory, GList **files)
+log_get_all_log_files_in_directory (const gchar  *directory, 
+				    GList       **files)
 {
 	GDir        *dir;
 	const gchar *name;
@@ -1054,36 +1078,6 @@ log_get_all_log_files_for_account_dir (const gchar  *account_dir,
 	g_dir_close (dir);
 }
 
-static void
-log_get_all_log_files_for_type_dir (const gchar  *type_dir,
-				    GList       **files)
-{
-	GDir        *dir;
-	const gchar *name;
-	gchar       *path;
-
-	dir = g_dir_open (type_dir, 0, NULL);
-	if (!dir) {
-		gossip_debug (DEBUG_DOMAIN, "Could not open directory:'%s'", type_dir);
-		return;
-	}
-
-	while ((name = g_dir_read_name (dir)) != NULL) {
-		path = g_build_filename (type_dir, name, NULL);
-
-		if (!g_file_test (path, G_FILE_TEST_IS_DIR)) {
-			g_free (path);
-			continue;
-		}
-
-		log_get_all_log_files_for_account_dir (path, files);
-
-		g_free (path);
-	}
-
-	g_dir_close (dir);
-}
-
 static gboolean
 log_get_all_log_files (GList **files)
 {
@@ -1110,7 +1104,7 @@ log_get_all_log_files (GList **files)
 
 	while ((name = g_dir_read_name (dir)) != NULL) {
 		account_dir = g_build_filename (log_directory, name, NULL);
-		log_get_all_log_files_for_type_dir (account_dir, files);
+		log_get_all_log_files_for_account_dir (account_dir, files);
 		g_free (account_dir);
 	}
 
@@ -1211,6 +1205,37 @@ log_get_filename_by_date_for_chatroom (GossipChatroom *chatroom,
 	return filename;
 }
 
+static gchar *
+log_get_filename_for_links (GossipAccount *account)
+{
+	gchar *filename;
+	gchar *dirname;
+	gchar *directory;
+
+	directory = log_get_basedir (account);
+	if (!directory) {
+		return NULL;
+	}
+
+	filename = g_build_filename (directory, "links.xml", NULL);
+	
+	g_free (directory);
+
+	gossip_debug (DEBUG_DOMAIN, "Using file:'%s' for link on account:'%s'",
+		      filename,
+		      gossip_account_get_name (account));
+
+	dirname = g_path_get_dirname (filename);
+	if (!g_file_test (dirname, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
+		gossip_debug (DEBUG_DOMAIN, "Creating directory:'%s'", dirname);
+		g_mkdir_with_parents (dirname, LOG_DIR_CREATE_MODE);
+	}
+
+	g_free (dirname);
+
+	return filename;
+}
+
 static gboolean
 log_set_name (GossipLogManager *manager,
 	      GossipContact    *contact)
@@ -1282,7 +1307,7 @@ gossip_log_get_contacts (GossipLogManager *manager, GossipAccount *account)
 			continue;
 		}
 
-		contacts = g_list_append (contacts, contact);
+		contacts = g_list_append (contacts, g_object_ref (contact));
 	}
 
 	g_free (directory);
@@ -1591,6 +1616,199 @@ gossip_log_get_messages_for_contact (GossipLogManager *manager,
 	return messages;
 }
 
+static void
+log_set_links_from_message (GossipLogManager *manager,
+			    GossipContact    *sender, 
+			    const gchar      *timestamp, 
+			    const gchar      *body)
+{
+	GArray   *start, *end;
+	GSList   *urls = NULL;
+	GSList   *l;
+	gchar    *filename;
+	FILE     *file;
+	gboolean  new_file;
+	gint      num_matches;
+	gint      i;
+
+	start = g_array_new (FALSE, FALSE, sizeof (gint));
+	end = g_array_new (FALSE, FALSE, sizeof (gint));
+	
+	/* Use Regex to find links */
+	num_matches = gossip_regex_match (GOSSIP_REGEX_ALL,
+					  body, 
+					  start, end);
+	
+	for (i = 0; i < num_matches; i++) {
+		gchar *url;
+		gchar *url_escaped;
+		gint   s = 0;
+		gint   e = 0;
+		
+		s = g_array_index (start, gint, i);
+		e = g_array_index (end, gint, i);
+		
+		url = gossip_substring (body, s, e);
+		if (!G_STR_EMPTY (url)) {
+			url_escaped = g_markup_escape_text (url, -1);
+			urls = g_slist_prepend (urls, url_escaped);
+		}
+		
+		g_free (url);
+	}
+
+	g_array_free (start, TRUE);
+	g_array_free (end, TRUE);
+
+	if (!urls) {
+		return;
+	}
+
+	urls = g_slist_reverse (urls);
+
+	/* Get filename to open */
+	filename = log_get_filename_for_links (gossip_contact_get_account (sender));
+	new_file = FALSE;
+	
+	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
+		file = g_fopen (filename, "w+");
+		if (file) {
+			g_fprintf (file, LOG_LINKS_FILE_HEADER);
+		}
+
+		new_file = TRUE;
+	} else {
+		file = g_fopen (filename, "r+");
+		if (file) {
+			fseek (file, - strlen (LOG_LINKS_FILE_FOOTER), SEEK_END);
+		}
+	}
+
+	for (l = urls; l; l = l->next) {
+		const gchar *url;
+
+		url = l->data;
+		
+		g_fprintf (file,
+			   "<link contact='%s' time='%s'>%s</link>\n",
+			   gossip_contact_get_id (sender),
+			   timestamp,
+			   url);
+	}
+	
+	g_fprintf (file, LOG_LINKS_FILE_FOOTER);
+
+	fclose (file);
+
+	if (new_file) {
+		g_chmod (filename, LOG_FILE_CREATE_MODE);
+	}
+
+	/* Clean up */
+	g_slist_foreach (urls, (GFunc) g_free, NULL);
+	g_slist_free (urls);
+	g_free (filename);
+}
+
+static GList *         
+log_get_links (GossipLogManager *manager, 
+	       GossipAccount    *account)
+{
+	GossipLogManagerPriv *priv;
+	GossipContactManager *contact_manager;
+	GList                *links = NULL;
+	gchar                *filename;
+	xmlParserCtxtPtr      ctxt;
+	xmlDocPtr             doc;
+	xmlNodePtr            log_node;
+	xmlNodePtr            node;
+
+	priv = GET_PRIV (manager);
+
+	contact_manager = gossip_session_get_contact_manager (priv->session);
+
+	filename = log_get_filename_for_links (account);
+
+	gossip_debug (DEBUG_DOMAIN, "Attempting to parse filename:'%s'...", filename);
+
+	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
+		gossip_debug (DEBUG_DOMAIN, "Filename:'%s' does not exist", filename);
+		g_free (filename);
+		return NULL;
+	}
+
+	/* Create parser. */
+	ctxt = xmlNewParserCtxt ();
+
+	/* Parse and validate the file. */
+	doc = xmlCtxtReadFile (ctxt, filename, NULL, 0);
+	if (!doc) {
+		g_warning ("Failed to parse file:'%s'", filename);
+		g_free (filename);
+		xmlFreeParserCtxt (ctxt);
+		return NULL;
+	}
+
+	/* The root node, presets. */
+	log_node = xmlDocGetRootElement (doc);
+	if (!log_node) {
+		g_free (filename);
+		xmlFreeDoc (doc);
+		xmlFreeParserCtxt (ctxt);
+		return NULL;
+	}
+
+	/* Now get the links. */
+	for (node = log_node->children; node; node = node->next) {
+		GossipLogLinkHit *hit;
+		GossipContact    *contact;
+		gchar            *contact_id;
+		gchar            *date;
+		gchar            *url;
+
+		if (strcmp (node->name, "link") != 0) {
+			continue;
+		}
+
+		contact_id = xmlGetProp (node, "contact");
+		contact = gossip_contact_manager_find (contact_manager, 
+						       account,
+						       contact_id);
+		xmlFree (contact_id);
+
+		date = xmlGetProp (node, "time");
+		url = xmlNodeGetContent (node);
+
+		hit = g_new0 (GossipLogLinkHit, 1);
+
+		hit->account = g_object_ref (account);
+
+		if (contact) {
+			hit->contact = g_object_ref (contact);
+		}
+
+		hit->date = g_strdup (date);
+		hit->url = g_strdup (url);
+		
+		links = g_list_prepend (links, hit);
+
+		xmlFree (date);
+		xmlFree (url);
+	}
+
+	if (links) {
+		links = g_list_reverse (links);
+	}
+
+	gossip_debug (DEBUG_DOMAIN, "Parsed %d links", g_list_length (links));
+
+	g_free (filename);
+	xmlFreeDoc (doc);
+	xmlFreeParserCtxt (ctxt);
+
+	return links;
+}
+
 void
 gossip_log_message_for_contact (GossipLogManager *manager,
 				GossipMessage    *message,
@@ -1642,6 +1860,7 @@ gossip_log_message_for_contact (GossipLogManager *manager,
 		own_contact = gossip_message_get_sender (message);
 	}
 
+	/* Continue */
 	account = gossip_contact_get_account (contact);
 	own_contact_saved = gossip_session_get_own_contact (priv->session, account);
 
@@ -1650,7 +1869,7 @@ gossip_log_message_for_contact (GossipLogManager *manager,
 	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
 		file = g_fopen (filename, "w+");
 		if (file) {
-			g_fprintf (file, LOG_HEADER);
+			g_fprintf (file, LOG_FILE_HEADER);
 		}
 
 		/* ONLY save the name when we create new files, we are
@@ -1665,7 +1884,7 @@ gossip_log_message_for_contact (GossipLogManager *manager,
 
 		file = g_fopen (filename, "r+");
 		if (file) {
-			fseek (file, - strlen (LOG_FOOTER), SEEK_END);
+			fseek (file, - strlen (LOG_FILE_FOOTER), SEEK_END);
 		}
 
 		/* Check the message name and our name match, if not
@@ -1727,7 +1946,7 @@ gossip_log_message_for_contact (GossipLogManager *manager,
 		   "<message time='%s' %s='%s' resource='%s' nick='%s'>"
 		   "%s"
 		   "</message>\n"
-		   LOG_FOOTER,
+		   LOG_FILE_FOOTER,
 		   timestamp,
 		   to_or_from,
 		   contact_id,
@@ -1741,14 +1960,21 @@ gossip_log_message_for_contact (GossipLogManager *manager,
 		g_chmod (filename, LOG_FILE_CREATE_MODE);
 	}
 
+	/* See if we should remember a link in the body of the message */
+	if (incoming) {
+		log_set_links_from_message (manager, contact, timestamp, body_str);
+	}
+
+	/* Notify all listening for new log events */
+	log_handlers_notify_all (manager, own_contact, contact, NULL, message);
+
+	/* Clean up */
 	g_free (filename);
 	g_free (timestamp);
 	g_free (body);
 	g_free (resource);
 	g_free (name);
 	g_free (contact_id);
-
-	log_handlers_notify_all (manager, own_contact, contact, NULL, message);
 }
 
 gboolean
@@ -2025,7 +2251,7 @@ gossip_log_message_for_chatroom (GossipLogManager *manager,
 	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
 		file = g_fopen (filename, "w+");
 		if (file) {
-			g_fprintf (file, LOG_HEADER);
+			g_fprintf (file, LOG_FILE_HEADER);
 		}
 
 		/* ONLY save the name when we create new files, we are
@@ -2036,7 +2262,7 @@ gossip_log_message_for_chatroom (GossipLogManager *manager,
 	} else {
 		file = g_fopen (filename, "r+");
 		if (file) {
-			fseek (file, - strlen (LOG_FOOTER), SEEK_END);
+			fseek (file, - strlen (LOG_FILE_FOOTER), SEEK_END);
 		}
 	}
 
@@ -2071,7 +2297,7 @@ gossip_log_message_for_chatroom (GossipLogManager *manager,
 		   "<message time='%s' from='%s' nick='%s'>"
 		   "%s"
 		   "</message>\n"
-		   LOG_FOOTER,
+		   LOG_FILE_FOOTER,
 		   timestamp,
 		   contact_id,
 		   name,
@@ -2083,13 +2309,20 @@ gossip_log_message_for_chatroom (GossipLogManager *manager,
 		g_chmod (filename, LOG_FILE_CREATE_MODE);
 	}
 
+	/* See if we should remember a link in the body of the message */
+	if (incoming) {
+		log_set_links_from_message (manager, contact, timestamp, body_str);
+	}
+
+	/* Notify all listening for new log events */
+	log_handlers_notify_all (manager, own_contact, NULL, chatroom, message);
+
+	/* Clean up */
 	g_free (timestamp);
 	g_free (body);
 	g_free (name);
 	g_free (contact_id);
 	g_free (filename);
-
-	log_handlers_notify_all (manager, own_contact, NULL, chatroom, message);
 }
 
 gboolean
@@ -2172,6 +2405,7 @@ gossip_log_search_new (GossipLogManager *manager,
 
 		/* FIXME: Handle chatrooms */
 		if (strstr (filename, LOG_DIR_CHATROOMS)) {
+			gossip_debug (DEBUG_DOMAIN, "Ignoring chatroom filename:'%s'", filename);
 			continue;
 		}
 
@@ -2190,6 +2424,7 @@ gossip_log_search_new (GossipLogManager *manager,
 		if (strstr (contents_casefold, text_casefold)) {
 			GossipLogSearchHit *hit;
 			GossipAccount      *account;
+			GossipContact      *contact;
 			gchar              *contact_id;
 
 			account = log_get_account_from_filename (manager, filename);
@@ -2198,27 +2433,40 @@ gossip_log_search_new (GossipLogManager *manager,
 				 * here which are not account
 				 * directories, so we just ignore them.
 				 */
+				g_warning ("No account for '%s', ignoring", filename);
 				continue;
 			}
 
 			contact_id = log_get_contact_id_from_filename (filename);
+			contact = gossip_contact_manager_find (contact_manager, 
+							       account, 
+							       contact_id);
+			if (!contact) {
+				/* FIXME: What do we do here, do we
+				 * create a new contact explicitly for
+				 * this log entry?
+				 */
+				g_warning ("No contact for '%s' (escaping contact id to '%s'), ignoring", 
+					   filename, contact_id);
+				g_free (contact_id);
+
+				continue;
+			}
+
+			g_free (contact_id);
 
 			hit = g_new0 (GossipLogSearchHit, 1);
 
 			hit->date = log_get_date_from_filename (filename);
 			hit->filename = g_strdup (filename);
 			hit->account = g_object_ref (account);
-			hit->contact = gossip_contact_manager_find (contact_manager, 
-								    account,
-								    contact_id);
+			hit->contact = g_object_ref (contact);
 
 			hits = g_list_append (hits, hit);
 
 			gossip_debug (DEBUG_DOMAIN, 
 				      "Found text:'%s' in file:'%s' on date:'%s'...",
 				      text, hit->filename, hit->date);
-
-			g_free (contact_id);
 		}
 
 		g_free (contents_casefold);
@@ -2291,3 +2539,251 @@ gossip_log_search_hit_get_filename (GossipLogSearchHit *hit)
 
 	return hit->filename;
 }
+
+/*
+ * Links
+ */
+
+void
+gossip_log_links_free (GList *hits)
+{
+	GList            *l;
+	GossipLogLinkHit *hit;
+
+	g_return_if_fail (hits != NULL);
+
+	for (l = hits; l; l = l->next) {
+		hit = l->data;
+
+		g_free (hit->url);
+		g_free (hit->date);
+
+		if (hit->contact) {
+			g_object_unref (hit->contact);
+		}
+
+		if (hit->account) {
+			g_object_unref (hit->account);
+		}
+
+		g_free (hit);
+	}
+
+	g_list_free (hits);
+}
+
+GList *
+gossip_log_get_links (GossipLogManager *manager,
+		      GossipAccount    *account)
+{
+	GossipLogManagerPriv *priv;
+	GossipAccountManager *account_manager;
+	GList                *accounts;
+	GList                *links = NULL;
+	GList                *l;
+
+	if (account) {
+		return log_get_links (manager, account);
+	}
+
+	priv = GET_PRIV (manager);
+
+	account_manager = gossip_session_get_account_manager (priv->session);
+	accounts = gossip_account_manager_get_accounts (account_manager);
+	for (l = accounts; l; l = l->next) {
+		links = g_list_concat (links, log_get_links (manager, l->data));
+		g_object_unref (l->data);
+	}
+	g_list_free (accounts);
+
+	return links;
+}
+
+GossipAccount *
+gossip_log_link_hit_get_account (GossipLogLinkHit *hit)
+{
+	g_return_val_if_fail (hit != NULL, NULL);
+
+	return hit->account;
+}
+
+GossipContact *
+gossip_log_link_hit_get_contact (GossipLogLinkHit *hit)
+{
+	g_return_val_if_fail (hit != NULL, NULL);
+
+	return hit->contact;
+}
+
+const gchar *     
+gossip_log_link_hit_get_date (GossipLogLinkHit *hit)
+{
+	g_return_val_if_fail (hit != NULL, NULL);
+
+	return hit->date;
+}
+
+const gchar *     
+gossip_log_link_hit_get_url (GossipLogLinkHit *hit)
+{
+	g_return_val_if_fail (hit != NULL, NULL);
+
+	return hit->url;
+}
+
+#if 0
+/* Function to convert links into new file format */
+GList *
+log_links_convert_old_to_new (GossipLogManager *manager)
+{
+	GossipLogManagerPriv *priv;
+	GossipContactManager *contact_manager;
+	GList                *files;
+	GList                *l;
+	const gchar          *filename;
+	gchar                *text_casefold = NULL;
+	gchar                *contents;
+	gchar                *contents_casefold;
+	GList                *hits = NULL;
+
+	g_return_val_if_fail (GOSSIP_IS_LOG_MANAGER (manager), NULL);
+
+	priv = GET_PRIV (manager);
+	
+	if (!G_STR_EMPTY (text)) {
+		text_casefold = g_utf8_casefold (text, -1);
+	}
+
+	if (log_get_all_log_files (&files)) {
+		gossip_debug (DEBUG_DOMAIN, "Found %d log files in total", g_list_length (files));
+	} else {
+		gossip_debug (DEBUG_DOMAIN, "Failed to retrieve all log files");
+	}
+
+	/* Do this here instead of for each file */
+	contact_manager = gossip_session_get_contact_manager (priv->session);
+
+	for (l = files; l; l = l->next) {
+		GMappedFile *file;
+		GArray      *start, *end;
+		gsize        length;
+		gint         num_matches;
+		gint         i;
+
+		filename = l->data;
+
+		/* FIXME: Handle chatrooms */
+		if (strstr (filename, LOG_DIR_CHATROOMS)) {
+			gossip_debug (DEBUG_DOMAIN, "Ignoring chatroom filename:'%s'", filename);
+			continue;
+		}
+
+		file = g_mapped_file_new (filename, FALSE, NULL);
+		if (!file) {
+			continue;
+		}
+
+		length = g_mapped_file_get_length (file);
+		contents = g_mapped_file_get_contents (file);
+
+		contents_casefold = g_utf8_casefold (contents, length);
+
+		g_mapped_file_free (file);
+
+		/* Use Regex to find links */
+		start = g_array_new (FALSE, FALSE, sizeof (gint));
+		end = g_array_new (FALSE, FALSE, sizeof (gint));
+		
+		num_matches = gossip_regex_match (GOSSIP_REGEX_BROWSER,
+						  contents_casefold, 
+						  start, end);
+		
+		for (i = 0; i < num_matches; i++) {
+			gchar    *link;
+			gint      s = 0;
+			gint      e = 0;
+			gboolean  add_link = TRUE;
+
+			s = g_array_index (start, gint, i);
+			e = g_array_index (end, gint, i);
+
+			link = gossip_substring (contents_casefold, s, e);
+			if (G_STR_EMPTY (link) ||
+			    (!G_STR_EMPTY (text_casefold) &&
+			     !strstr (contents_casefold, text_casefold))) {
+				add_link = FALSE;
+			}
+
+			if (add_link) {
+				GossipLogSearchHit *hit;
+				GossipAccount      *account;
+				GossipContact      *contact;
+				gchar              *contact_id;
+				gint                len;
+
+				/* FIX a nasty issue where we get the
+				 * </message> in part in the URL from
+				 * the log file format.
+				 */
+				len = strlen (link);
+				if (link[len - 1] == '<') {
+					link[len - 1] = '\0';
+				}
+				
+				account = log_get_account_from_filename (manager, filename);
+				if (!account) {
+					/* We must have other directories in
+					 * here which are not account
+					 * directories, so we just ignore them.
+					 */
+					g_free (link);
+					continue;
+				}
+				
+				contact_id = log_get_contact_id_from_filename (filename);
+				contact = gossip_contact_manager_find (contact_manager, 
+								       account, 
+								       contact_id);
+				g_free (contact_id);
+				
+				if (!contact) {
+					g_free (link);
+					continue;
+				}
+				
+				/* FIXME: Add function call here to remember link 
+				 *
+				 */
+				
+				hit = g_new0 (GossipLogSearchHit, 1);
+				
+				hit->date = log_get_date_from_filename (filename);
+				hit->filename = g_strdup (filename);
+				hit->account = g_object_ref (account);
+				hit->contact = g_object_ref (contact);
+				hit->link = link;
+
+				gossip_debug (DEBUG_DOMAIN, 
+					      "Found link:'%s' in file:'%s' on date:'%s'...",
+					      link, hit->filename, hit->date);
+				continue;
+			}
+			
+			g_free (link);
+		}
+
+		g_array_free (start, TRUE);
+		g_array_free (end, TRUE);
+
+		g_free (contents_casefold);
+	}
+
+	g_list_foreach (files, (GFunc) g_free, NULL);
+	g_list_free (files);
+
+	g_free (text_casefold);
+
+	return hits;
+}
+
+#endif
