@@ -16,9 +16,6 @@
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
- *
- * Authors: Richard Hult <richard@imendio.com>
- *          Martyn Russell <martyn@imendio.com>
  */
 
 #ifndef __GOSSIP_PRESENCE_CHOOSER_H__
@@ -54,15 +51,6 @@ void       gossip_presence_chooser_set_state          (GossipPresenceChooser *ch
 						       GossipPresenceState    state);
 void       gossip_presence_chooser_set_status         (GossipPresenceChooser *chooser,
 						       const gchar           *status);
-void       gossip_presence_chooser_set_flash_interval (GossipPresenceChooser *chooser,
-						       guint                  ms);
-
-void       gossip_presence_chooser_flash_start        (GossipPresenceChooser *chooser,
-						       GossipPresenceState    state_1,
-						       GossipPresenceState    state_2);
-void       gossip_presence_chooser_flash_stop         (GossipPresenceChooser *chooser,
-						       GossipPresenceState    state);
-gboolean   gossip_presence_chooser_is_flashing        (GossipPresenceChooser *chooser);
 
 G_END_DECLS
 
